<?php
   /*
   Plugin Name: Remove Free Shipping On Specific Coupons For Woocommerce
   Plugin URI: http://qwebmaster.com/remove-free-shipping-on-specific-coupons-for-woocommerce/
   Description: Removes free shipping option if a secific coupon is used. 
   Version: 1.0
   Requires at least: 4.0
   Tested up to: 5.6
   Requires PHP: 7.3
   Author: Qwebmaster
   Author URI: http://qwebmaster.com
   */

   if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


    add_filter( 'woocommerce_package_rates', 'qwebmaster_rfsc_remove_free_shipping_method_based_on_coupon', 10, 2 );
    function qwebmaster_rfsc_remove_free_shipping_method_based_on_coupon( $rates, $package )
    {
        //  First, If there are no coupons Skip
        $applied_coupons    = WC()->cart->get_applied_coupons(); // Applied coupons
        if( empty($applied_coupons) )
            return $rates;

     // Get Applied coupons and check if the remove free shipping box is checked 
     $disable_free_shipping = 0;
     foreach ($applied_coupons as $key => $coupon) {
        // Create coupon OBJECT and get ID 
        $coupon_post_obj = get_page_by_title($coupon, OBJECT, 'shop_coupon');
        $coupon_id       = $coupon_post_obj->ID;
        // Get Custom Checkbox Meta Value
        $disable_free_shipping = get_post_meta( $coupon_id, 'disable_free_shipping', true );
        if ($disable_free_shipping === 'yes'){
           // If Disable free shipping disable checkbox is found in any one of the coupons stop the loop and disable free shipping.
           $disable_free_shipping = 1;
           break;
        }
     }


        // Disable Free Shipping
       if($disable_free_shipping === 1 ) {
            foreach ( $rates as $rate_key => $rate ) {
                // Targetting "Free shipping"
                if ( 'free_shipping' === $rate->method_id ) {
                    unset($rates[$rate_key]); // hide free shipping method
                }
            }
        }
        return $rates;
    }

    function qwebmaster_rfsc_add_coupon_checkbox() { 
        woocommerce_wp_checkbox( array( 'id' => 'disable_free_shipping', 'label' => __( 'Disable Free Shipping', 'woocommerce' ), 'description' => sprintf( __( 'When Checked, the free shipping method will be removed anytime this coupon is used.', 'woocommerce' ) ) ) );
    }
    add_action( 'woocommerce_coupon_options', 'qwebmaster_rfsc_add_coupon_checkbox', 10, 0 );

    function qwebmaster_rfsc_save_coupon_checkbox( $post_id ) {
        $disable_free_shipping = isset( $_POST['disable_free_shipping'] ) ? 'yes' : 'no';
        update_post_meta( $post_id, 'disable_free_shipping', $disable_free_shipping );
        //unset(WC()->session->$shipping_session);
    }
    add_action( 'woocommerce_coupon_options_save', 'qwebmaster_rfsc_save_coupon_checkbox');